#define MOZ_SOURCE_STAMP 89857f35df2914762f833b0be2cf27b90328a265
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-esr52
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-esr52/rev/89857f35df2914762f833b0be2cf27b90328a265
